public inbox for libc-alpha@sourceware.org
 help / color / mirror / Atom feed
* [patch committed] strcoll_l, strxfrm_l are standardized now
@ 2016-11-16 19:47 Zack Weinberg
  0 siblings, 0 replies; only message in thread
From: Zack Weinberg @ 2016-11-16 19:47 UTC (permalink / raw)
  To: GNU C Library

I have checked in the following patch, which corrects comments in
string.h.  strcoll_l and strxfrm_l are in POSIX.1-2008, and are
correctly under #ifdef __USE_XOPEN2K8, but the comments say that they
have not yet been standardized.

zw

	* string/string.h: Remove obsolete comment stating that
	strcoll_l and strxfrm_l have not yet been standardized.

diff --git a/string/string.h b/string/string.h
index 57deaa4..b103e64 100644
--- a/string/string.h
+++ b/string/string.h
@@ -154,15 +154,13 @@ extern size_t strxfrm (char *__restrict __dest,
 __END_NAMESPACE_STD

 #ifdef __USE_XOPEN2K8
-/* The following functions are equivalent to the both above but they
-   take the locale they use for the collation as an extra argument.
-   This is not standardsized but something like will come.  */
 # include <xlocale.h>

 /* Compare the collated forms of S1 and S2 using rules from L.  */
 extern int strcoll_l (const char *__s1, const char *__s2, __locale_t __l)
      __THROW __attribute_pure__ __nonnull ((1, 2, 3));
-/* Put a transformation of SRC into no more than N bytes of DEST.  */
+/* Put a transformation of SRC into no more than N bytes of DEST,
+   using sorting rules from L.  */
 extern size_t strxfrm_l (char *__dest, const char *__src, size_t __n,
                         __locale_t __l) __THROW __nonnull ((2, 4));
 #endif

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2016-11-16 19:47 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -154,15 +154,13 @@ extern size_t strxfrm (char *__restrict __dest,
 # include <xlocale.h>

-/* Compare the collated forms of S1 and S2 using rules from L.  */
+/* Compare the collated forms of S1 and S2, using sorting rules from L.  */
 extern int strcoll_l (const char *__s1, const char *__s2, __locale_t __l)
      __THROW __attribute_pure__ __nonnull ((1, 2, 3));
2016-11-16 19:47 [patch committed] strcoll_l, strxfrm_l are standardized now Zack Weinberg

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).